@@ -5,8 +5,7 @@ use File::Path ();
 use File::Basename ();
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.27_07';
-$VERSION = eval $VERSION;
+$VERSION = '0.01';
 
 # Okay, this is the brute-force method of finding out what kind of
 # platform we're on.  I don't know of a systematic way.  These values
@@ -36,9 +35,6 @@ my %OSTYPES = qw(
 		 sunos     Unix
 		 cygwin    Unix
 		 os2       Unix
-		 gnu       Unix
-		 gnukfreebsd Unix
-		 haiku     Unix
 		 
 		 dos       Windows
 		 MSWin32   Windows
@@ -120,22 +116,11 @@ by the object, as in the following example:
   my $b = ExtUtils::CBuilder->new( config =>
                                    { ld => 'gcc' } );
 
-A C<quiet> parameter tells C<CBuilder> to not print its C<system()>
-commands before executing them:
-
-  # Be quieter than normal
-  my $b = ExtUtils::CBuilder->new( quiet => 1 );
-
 =item have_compiler
 
 Returns true if the current system has a working C compiler and
 linker, false otherwise.  To determine this, we actually compile and
-link a sample C library.  The sample will be compiled in the system
-tempdir or, if that fails for some reason, in the current directory.
-
-=item have_cplusplus
-
-Just like have_compiler but for C++ instead of C.
+link a sample C library.
 
 =item compile
 
@@ -165,15 +150,10 @@ given as a list reference containing the arguments individually, or if
 this is not possible, as a string containing all the arguments
 together.
 
-=item C<C++>
-
-Specifies that the source file is a C++ source file and sets appropriate
-compiler flags
-
 =back
 
 The operation of this method is also affected by the
-C<archlibexp>, C<cccdlflags>, C<ccflags>, C<optimize>, and C<cc>
+C<installarchlib>, C<cccdlflags>, C<ccflags>, C<optimize>, and C<cc>
 entries in C<Config.pm>.
 
 =item link
@@ -186,7 +166,6 @@ object files to process, either in a string (for one object file) or
 list reference (for one or more files).  The following parameters are
 optional:
 
-
 =over 4
 
 =item lib_file
@@ -213,27 +192,6 @@ will be called automatically.
 The operation of this method is also affected by the C<lddlflags>,
 C<shrpenv>, and C<ld> entries in C<Config.pm>.
 
-=item link_executable
-
-Invokes the linker to produce an executable file from object files.  In
-scalar context, the name of the executable file is returned.  In list
-context, the executable file and any temporary files created are
-returned.  A required C<objects> parameter contains the name of the
-object files to process, either in a string (for one object file) or
-list reference (for one or more files).  The optional parameters are
-the same as C<link> with exception for
-
-
-=over 4
-
-=item exe_file
-
-Specifies the name of the output executable file to create.  Otherwise
-the C<exe_file()> method will be consulted, passing it the name of the
-first entry in C<objects>.
-
-=back
-
 =item object_file
 
  my $object_file = $b->object_file($source_file);
@@ -250,16 +208,6 @@ Converts the name of an object file to the most natural name of a
 output library file to create from it.  For instance, on Mac OS X the
 object file F<foo.o> would result in the library file F<foo.bundle>.
 
-=item exe_file
-
- my $exe_file = $b->exe_file($object_file);
-
-Converts the name of an object file to the most natural name of an
-executable file to create from it.  For instance, on Mac OS X the
-object file F<foo.o> would result in the executable file F<foo>, and
-on Windows it would result in F<foo.exe>.
-
-
 =item prelink
 
 On certain platforms like Win32, OS/2, VMS, and AIX, it is necessary
@@ -271,7 +219,7 @@ The names of any files written will be returned as a list.
 Several parameters correspond to C<ExtUtils::Mksymlists::Mksymlists()>
 options, as follows:
 
-    Mksymlists()   prelink()          type
+    Mksymlists()  prelink_objects()       type
    -------------|-------------------|-------------------
     NAME        |  dl_name          | string (required)
     DLBASE      |  dl_base          | string
@@ -280,7 +228,6 @@ options, as follows:
     DL_FUNCS    |  dl_funcs         | hash reference
     FUNCLIST    |  dl_func_list     | array reference
     IMPORTS     |  dl_imports       | hash reference
-    VERSION     |  dl_version       | string
 
 Please see the documentation for C<ExtUtils::Mksymlists> for the
 details of what these parameters do.
@@ -290,12 +237,6 @@ details of what these parameters do.
 Returns true on platforms where C<prelink()> should be called
 during linking, and false otherwise.
 
-=item extra_link_args_after_prelink
-
-Returns list of extra arguments to give to the link command; the arguments
-are the same as for prelink(), with addition of array reference to the
-results of prelink(); this reference is indexed by key C<prelink_res>.
-
 =back
 
 =head1 TO DO
@@ -309,21 +250,12 @@ that next.
 This module is an outgrowth of the C<Module::Build> project, to which
 there have been many contributors.  Notably, Randy W. Sims submitted
 lots of code to support 3 compilers on Windows and helped with various
-other platform-specific issues.  Ilya Zakharevich has contributed
-fixes for OS/2; John E. Malmberg and Peter Prymmer have done likewise
-for VMS.
+other platform-specific issues.
 
 =head1 AUTHOR
 
 Ken Williams, kwilliams@cpan.org
 
-=head1 COPYRIGHT
-
-Copyright (c) 2003-2005 Ken Williams.  All rights reserved.
-
-This library is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
-
 =head1 SEE ALSO
 
 perl(1), Module::Build(3)
